aboutsummaryrefslogtreecommitdiffstats
path: root/src/main/javassist/CtMember.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/javassist/CtMember.java')
-rw-r--r--src/main/javassist/CtMember.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/main/javassist/CtMember.java b/src/main/javassist/CtMember.java
index 63a26b56..3c5da768 100644
--- a/src/main/javassist/CtMember.java
+++ b/src/main/javassist/CtMember.java
@@ -208,9 +208,9 @@ public abstract class CtMember {
public abstract void setModifiers(int mod);
/**
* Returns true if the class has the specified annotation class.
*
* @param clz the annotation class.
* @return <code>true</code> if the annotation is found, otherwise <code>false</code>.
* @since 3.11
*/
@@ -219,26 +219,26 @@ public abstract class CtMember {
}
/**
* Returns true if the class has the specified annotation class.
*
* @param annotClzName the name of annotation class.
* @return <code>true</code> if the annotation is found, otherwise <code>false</code>.
- * @since 3.11
+ * @since 3.21
*/
- public abstract boolean hasAnnotation(String annotClzName);
+ public abstract boolean hasAnnotation(String annotationTypeName);
/**
* Returns the annotation if the class has the specified annotation class.
* For example, if an annotation <code>@Author</code> is associated
* with this member, an <code>Author</code> object is returned.
* The member values can be obtained by calling methods on
* the <code>Author</code> object.
*
* @param clz the annotation class.
* @return the annotation if found, otherwise <code>null</code>.
* @since 3.11
*/
- public abstract Object getAnnotation(Class clz) throws ClassNotFoundException;
+ public abstract Object getAnnotation(Class annotationType) throws ClassNotFoundException;
/**
* Returns the annotations associated with this member.
@@ -208,9 +208,9 @@ public abstract class CtMember {
public abstract void setModifiers(int mod);
/**
- * Returns true if the class has the specified annotation class.
+ * Returns true if the class has the specified annotation type.
*
@@ -208,9 +208,9 @@ public abstract class CtMember {
*
- * @param clz the annotation class.
+ * @param clz the annotation type.
* @return <code>true</code> if the annotation is found, otherwise <code>false</code>.
* @since 3.11
@@ -219,26 +219,26 @@ public abstract class CtMember {
}
/**
- * Returns true if the class has the specified annotation class.
+ * Returns true if the class has the specified annotation type.
*
@@ -219,26 +219,26 @@ public abstract class CtMember {
*
- * @param annotClzName the name of annotation class.
+ * @param annotationTypeName the name of annotation type.
* @return <code>true</code> if the annotation is found, otherwise <code>false</code>.
@@ -219,26 +219,26 @@ public abstract class CtMember {
/**
- * Returns the annotation if the class has the specified annotation class.
+ * Returns the annotation if the class has the specified annotation type.
* For example, if an annotation <code>@Author</code> is associated
* with this member, an <code>Author</code> object is returned.
@@ -219,26 +219,26 @@ public abstract class CtMember {
* the <code>Author</code> object.
*
- * @param clz the annotation class.
+ * @param annotationType the annotation type.
* @return the annotation if found, otherwise <code>null</code>.
* @since 3.11